custom_sched_mixed

Function custom_sched_mixed 

pub fn custom_sched_mixed(ctx: &Ctx<'_>) -> Result<AssertResult>
Two cgroups each running Normal, Batch, Idle, and FIFO(1) workers concurrently. FIFO workers use bursty workloads to avoid monopolizing CPUs.