execute_steps

Function execute_steps 

pub fn execute_steps(ctx: &Ctx<'_>, steps: Vec<Step>) -> Result<AssertResult>
Execute a sequence of steps against the given context.

Convenience wrapper around execute_steps_with that passes None for checks, falling back to ctx.assert. Use execute_steps_with when you need to override ctx.assert.