pub fn affinity_change(ctx: &Ctx<'_>) -> Result<AssertResult>Expand description
Two cgroups with worker affinities randomized mid-run.
Workers start with no affinity, then get random CPU subsets applied four times during the run.
pub fn affinity_change(ctx: &Ctx<'_>) -> Result<AssertResult>Two cgroups with worker affinities randomized mid-run.
Workers start with no affinity, then get random CPU subsets applied four times during the run.