cpuset_clear

Function cpuset_clear 

pub fn cpuset_clear(ctx: &Ctx<'_>) -> Result<AssertResult>
Two cgroups start with disjoint cpusets, then cpusets are cleared mid-run.

Tests the scheduler’s response to cpuset removal. Workers that were confined to a subset of CPUs become free to run anywhere.