pub fn oversubscribed(ctx: &Ctx<'_>) -> Result<AssertResult>Expand description
Two cgroups with 32 mixed workers each (oversubscribed).
Worker count far exceeds CPU count, testing dispatch under heavy oversubscription with mixed workload types.
pub fn oversubscribed(ctx: &Ctx<'_>) -> Result<AssertResult>Two cgroups with 32 mixed workers each (oversubscribed).
Worker count far exceeds CPU count, testing dispatch under heavy oversubscription with mixed workload types.