pub fn steady(ctx: &Ctx<'_>) -> Result<AssertResult>Expand description
Two cgroups, no cpusets, equal CPU-spin load.
Simplest possible scenario: tests that the scheduler can handle two cgroups running simultaneously without starvation.
pub fn steady(ctx: &Ctx<'_>) -> Result<AssertResult>Two cgroups, no cpusets, equal CPU-spin load.
Simplest possible scenario: tests that the scheduler can handle two cgroups running simultaneously without starvation.