pub fn custom_cgroup_exhaust_reuse(ctx: &Ctx<'_>) -> Result<AssertResult>Expand description
Exhaust cgroup slots with empty cpuset-pinned cgroups, remove half, then create replacement cgroups with workers to test slot reuse.
pub fn custom_cgroup_exhaust_reuse(ctx: &Ctx<'_>) -> Result<AssertResult>Exhaust cgroup slots with empty cpuset-pinned cgroups, remove half, then create replacement cgroups with workers to test slot reuse.