pub fn custom_cgroup_workload_variety(ctx: &Ctx<'_>) -> Result<AssertResult>Expand description
Uses spawn_diverse helper for 5 different workload types across cgroups. Dynamic cgroup count and workload rotation logic is not Op/Step compatible.
pub fn custom_cgroup_workload_variety(ctx: &Ctx<'_>) -> Result<AssertResult>Uses spawn_diverse helper for 5 different workload types across cgroups. Dynamic cgroup count and workload rotation logic is not Op/Step compatible.