pub fn cgroup_remove(ctx: &Ctx<'_>) -> Result<AssertResult>Expand description
Four cgroups initially, then the second half removed mid-run.
Tests the scheduler’s response to cgroup removal while workers in surviving cgroups continue running.
pub fn cgroup_remove(ctx: &Ctx<'_>) -> Result<AssertResult>Four cgroups initially, then the second half removed mid-run.
Tests the scheduler’s response to cgroup removal while workers in surviving cgroups continue running.