pub fn extract_verifier_log(scheduler_log: &str) -> Option<&str>Expand description
Extract the verifier instruction trace from a scheduler log blob.
libbpf wraps the kernel verifier log between marker lines:
-- BEGIN PROG LOAD LOG --
-- END PROG LOAD LOG --
Returns the content between the first pair of markers, or None if
no markers are found (backward compat with logs that contain only
raw verifier output).